# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/promotion_extension_occasion.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/promotion_extension_occasion.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\037PromotionExtensionOccasionProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nFgoogle/ads/googleads_v1/proto/enums/promotion_extension_occasion.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xbc\x05\n\x1ePromotionExtensionOccasionEnum\"\x99\x05\n\x1aPromotionExtensionOccasion\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\r\n\tNEW_YEARS\x10\x02\x12\x14\n\x10\x43HINESE_NEW_YEAR\x10\x03\x12\x12\n\x0eVALENTINES_DAY\x10\x04\x12\n\n\x06\x45\x41STER\x10\x05\x12\x0f\n\x0bMOTHERS_DAY\x10\x06\x12\x0f\n\x0b\x46\x41THERS_DAY\x10\x07\x12\r\n\tLABOR_DAY\x10\x08\x12\x12\n\x0e\x42\x41\x43K_TO_SCHOOL\x10\t\x12\r\n\tHALLOWEEN\x10\n\x12\x10\n\x0c\x42LACK_FRIDAY\x10\x0b\x12\x10\n\x0c\x43YBER_MONDAY\x10\x0c\x12\r\n\tCHRISTMAS\x10\r\x12\x0e\n\nBOXING_DAY\x10\x0e\x12\x14\n\x10INDEPENDENCE_DAY\x10\x0f\x12\x10\n\x0cNATIONAL_DAY\x10\x10\x12\x11\n\rEND_OF_SEASON\x10\x11\x12\x0f\n\x0bWINTER_SALE\x10\x12\x12\x0f\n\x0bSUMMER_SALE\x10\x13\x12\r\n\tFALL_SALE\x10\x14\x12\x0f\n\x0bSPRING_SALE\x10\x15\x12\x0b\n\x07RAMADAN\x10\x16\x12\x0f\n\x0b\x45ID_AL_FITR\x10\x17\x12\x0f\n\x0b\x45ID_AL_ADHA\x10\x18\x12\x0f\n\x0bSINGLES_DAY\x10\x19\x12\x0e\n\nWOMENS_DAY\x10\x1a\x12\x08\n\x04HOLI\x10\x1b\x12\x0f\n\x0bPARENTS_DAY\x10\x1c\x12\x13\n\x0fST_NICHOLAS_DAY\x10\x1d\x12\x0c\n\x08\x43\x41RNIVAL\x10\x1e\x12\x0c\n\x08\x45PIPHANY\x10\x1f\x12\x11\n\rROSH_HASHANAH\x10 \x12\x0c\n\x08PASSOVER\x10!\x12\x0c\n\x08HANUKKAH\x10\"\x12\n\n\x06\x44IWALI\x10#\x12\x0c\n\x08NAVRATRI\x10$\x12\x0c\n\x08SONGKRAN\x10%\x12\x11\n\rYEAR_END_GIFT\x10&B\xf4\x01\n!com.google.ads.googleads.v1.enumsB\x1fPromotionExtensionOccasionProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION = _descriptor.EnumDescriptor(
  name='PromotionExtensionOccasion',
  full_name='google.ads.googleads.v1.enums.PromotionExtensionOccasionEnum.PromotionExtensionOccasion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEW_YEARS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHINESE_NEW_YEAR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALENTINES_DAY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EASTER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOTHERS_DAY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FATHERS_DAY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LABOR_DAY', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BACK_TO_SCHOOL', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HALLOWEEN', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BLACK_FRIDAY', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CYBER_MONDAY', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHRISTMAS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOXING_DAY', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INDEPENDENCE_DAY', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NATIONAL_DAY', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END_OF_SEASON', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WINTER_SALE', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUMMER_SALE', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FALL_SALE', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPRING_SALE', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RAMADAN', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EID_AL_FITR', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EID_AL_ADHA', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINGLES_DAY', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WOMENS_DAY', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOLI', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARENTS_DAY', index=28, number=28,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_NICHOLAS_DAY', index=29, number=29,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARNIVAL', index=30, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EPIPHANY', index=31, number=31,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ROSH_HASHANAH', index=32, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PASSOVER', index=33, number=33,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HANUKKAH', index=34, number=34,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIWALI', index=35, number=35,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAVRATRI', index=36, number=36,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SONGKRAN', index=37, number=37,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YEAR_END_GIFT', index=38, number=38,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=171,
  serialized_end=836,
)
_sym_db.RegisterEnumDescriptor(_PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION)


_PROMOTIONEXTENSIONOCCASIONENUM = _descriptor.Descriptor(
  name='PromotionExtensionOccasionEnum',
  full_name='google.ads.googleads.v1.enums.PromotionExtensionOccasionEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=136,
  serialized_end=836,
)

_PROMOTIONEXTENSIONOCCASIONENUM_PROMOTIONEXTENSIONOCCASION.containing_type = _PROMOTIONEXTENSIONOCCASIONENUM
DESCRIPTOR.message_types_by_name['PromotionExtensionOccasionEnum'] = _PROMOTIONEXTENSIONOCCASIONENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PromotionExtensionOccasionEnum = _reflection.GeneratedProtocolMessageType('PromotionExtensionOccasionEnum', (_message.Message,), dict(
  DESCRIPTOR = _PROMOTIONEXTENSIONOCCASIONENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.promotion_extension_occasion_pb2'
  ,
  __doc__ = """Container for enum describing a promotion extension occasion. For more
  information about the occasions please check:
  https://support.google.com/google-ads/answer/7367521
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.PromotionExtensionOccasionEnum)
  ))
_sym_db.RegisterMessage(PromotionExtensionOccasionEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/ad.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import ad_type_infos_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2
from google.ads.google_ads.v1.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v1.proto.common import final_app_url_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_final__app__url__pb2
from google.ads.google_ads.v1.proto.common import url_collection_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_url__collection__pb2
from google.ads.google_ads.v1.proto.enums import ad_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__type__pb2
from google.ads.google_ads.v1.proto.enums import device_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_device__pb2
from google.ads.google_ads.v1.proto.enums import system_managed_entity_source_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_system__managed__entity__source__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/ad.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\007AdProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n0google/ads/googleads_v1/proto/resources/ad.proto\x12!google.ads.googleads.v1.resources\x1a\x38google/ads/googleads_v1/proto/common/ad_type_infos.proto\x1a;google/ads/googleads_v1/proto/common/custom_parameter.proto\x1a\x38google/ads/googleads_v1/proto/common/final_app_url.proto\x1a\x39google/ads/googleads_v1/proto/common/url_collection.proto\x1a\x31google/ads/googleads_v1/proto/enums/ad_type.proto\x1a\x30google/ads/googleads_v1/proto/enums/device.proto\x1a\x46google/ads/googleads_v1/proto/enums/system_managed_entity_source.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x8b\x12\n\x02\x41\x64\x12\'\n\x02id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\nfinal_urls\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\x0e\x66inal_app_urls\x18# \x03(\x0b\x32+.google.ads.googleads.v1.common.FinalAppUrl\x12\x37\n\x11\x66inal_mobile_urls\x18\x10 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15tracking_url_template\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x15url_custom_parameters\x18\n \x03(\x0b\x32/.google.ads.googleads.v1.common.CustomParameter\x12\x31\n\x0b\x64isplay_url\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x04type\x18\x05 \x01(\x0e\x32\x30.google.ads.googleads.v1.enums.AdTypeEnum.AdType\x12\x37\n\x13\x61\x64\x64\x65\x64_by_google_ads\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\x11\x64\x65vice_preference\x18\x14 \x01(\x0e\x32\x30.google.ads.googleads.v1.enums.DeviceEnum.Device\x12\x46\n\x0furl_collections\x18\x1a \x03(\x0b\x32-.google.ads.googleads.v1.common.UrlCollection\x12*\n\x04name\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x82\x01\n\x1esystem_managed_resource_source\x18\x1b \x01(\x0e\x32Z.google.ads.googleads.v1.enums.SystemManagedResourceSourceEnum.SystemManagedResourceSource\x12=\n\x07text_ad\x18\x06 \x01(\x0b\x32*.google.ads.googleads.v1.common.TextAdInfoH\x00\x12N\n\x10\x65xpanded_text_ad\x18\x07 \x01(\x0b\x32\x32.google.ads.googleads.v1.common.ExpandedTextAdInfoH\x00\x12\x46\n\x0c\x63\x61ll_only_ad\x18\r \x01(\x0b\x32..google.ads.googleads.v1.common.CallOnlyAdInfoH\x00\x12\x61\n\x1a\x65xpanded_dynamic_search_ad\x18\x0e \x01(\x0b\x32;.google.ads.googleads.v1.common.ExpandedDynamicSearchAdInfoH\x00\x12?\n\x08hotel_ad\x18\x0f \x01(\x0b\x32+.google.ads.googleads.v1.common.HotelAdInfoH\x00\x12P\n\x11shopping_smart_ad\x18\x11 \x01(\x0b\x32\x33.google.ads.googleads.v1.common.ShoppingSmartAdInfoH\x00\x12T\n\x13shopping_product_ad\x18\x12 \x01(\x0b\x32\x35.google.ads.googleads.v1.common.ShoppingProductAdInfoH\x00\x12?\n\x08gmail_ad\x18\x15 \x01(\x0b\x32+.google.ads.googleads.v1.common.GmailAdInfoH\x00\x12?\n\x08image_ad\x18\x16 \x01(\x0b\x32+.google.ads.googleads.v1.common.ImageAdInfoH\x00\x12?\n\x08video_ad\x18\x18 \x01(\x0b\x32+.google.ads.googleads.v1.common.VideoAdInfoH\x00\x12V\n\x14responsive_search_ad\x18\x19 \x01(\x0b\x32\x36.google.ads.googleads.v1.common.ResponsiveSearchAdInfoH\x00\x12\x65\n\x1clegacy_responsive_display_ad\x18\x1c \x01(\x0b\x32=.google.ads.googleads.v1.common.LegacyResponsiveDisplayAdInfoH\x00\x12;\n\x06\x61pp_ad\x18\x1d \x01(\x0b\x32).google.ads.googleads.v1.common.AppAdInfoH\x00\x12W\n\x15legacy_app_install_ad\x18\x1e \x01(\x0b\x32\x36.google.ads.googleads.v1.common.LegacyAppInstallAdInfoH\x00\x12X\n\x15responsive_display_ad\x18\x1f \x01(\x0b\x32\x37.google.ads.googleads.v1.common.ResponsiveDisplayAdInfoH\x00\x12P\n\x11\x64isplay_upload_ad\x18! \x01(\x0b\x32\x33.google.ads.googleads.v1.common.DisplayUploadAdInfoH\x00\x12P\n\x11\x61pp_engagement_ad\x18\" \x01(\x0b\x32\x33.google.ads.googleads.v1.common.AppEngagementAdInfoH\x00\x12i\n\x1eshopping_comparison_listing_ad\x18$ \x01(\x0b\x32?.google.ads.googleads.v1.common.ShoppingComparisonListingAdInfoH\x00\x42\t\n\x07\x61\x64_dataB\xf4\x01\n%com.google.ads.googleads.v1.resourcesB\x07\x41\x64ProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_final__app__url__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_url__collection__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_device__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_system__managed__entity__source__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_AD = _descriptor.Descriptor(
  name='Ad',
  full_name='google.ads.googleads.v1.resources.Ad',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.Ad.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_urls', full_name='google.ads.googleads.v1.resources.Ad.final_urls', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_app_urls', full_name='google.ads.googleads.v1.resources.Ad.final_app_urls', index=2,
      number=35, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_mobile_urls', full_name='google.ads.googleads.v1.resources.Ad.final_mobile_urls', index=3,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tracking_url_template', full_name='google.ads.googleads.v1.resources.Ad.tracking_url_template', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v1.resources.Ad.url_custom_parameters', index=5,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_url', full_name='google.ads.googleads.v1.resources.Ad.display_url', index=6,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.resources.Ad.type', index=7,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='added_by_google_ads', full_name='google.ads.googleads.v1.resources.Ad.added_by_google_ads', index=8,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_preference', full_name='google.ads.googleads.v1.resources.Ad.device_preference', index=9,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_collections', full_name='google.ads.googleads.v1.resources.Ad.url_collections', index=10,
      number=26, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.Ad.name', index=11,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_managed_resource_source', full_name='google.ads.googleads.v1.resources.Ad.system_managed_resource_source', index=12,
      number=27, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_ad', full_name='google.ads.googleads.v1.resources.Ad.text_ad', index=13,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expanded_text_ad', full_name='google.ads.googleads.v1.resources.Ad.expanded_text_ad', index=14,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_only_ad', full_name='google.ads.googleads.v1.resources.Ad.call_only_ad', index=15,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expanded_dynamic_search_ad', full_name='google.ads.googleads.v1.resources.Ad.expanded_dynamic_search_ad', index=16,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hotel_ad', full_name='google.ads.googleads.v1.resources.Ad.hotel_ad', index=17,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shopping_smart_ad', full_name='google.ads.googleads.v1.resources.Ad.shopping_smart_ad', index=18,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shopping_product_ad', full_name='google.ads.googleads.v1.resources.Ad.shopping_product_ad', index=19,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gmail_ad', full_name='google.ads.googleads.v1.resources.Ad.gmail_ad', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_ad', full_name='google.ads.googleads.v1.resources.Ad.image_ad', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video_ad', full_name='google.ads.googleads.v1.resources.Ad.video_ad', index=22,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='responsive_search_ad', full_name='google.ads.googleads.v1.resources.Ad.responsive_search_ad', index=23,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_responsive_display_ad', full_name='google.ads.googleads.v1.resources.Ad.legacy_responsive_display_ad', index=24,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_ad', full_name='google.ads.googleads.v1.resources.Ad.app_ad', index=25,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_app_install_ad', full_name='google.ads.googleads.v1.resources.Ad.legacy_app_install_ad', index=26,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='responsive_display_ad', full_name='google.ads.googleads.v1.resources.Ad.responsive_display_ad', index=27,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_upload_ad', full_name='google.ads.googleads.v1.resources.Ad.display_upload_ad', index=28,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_engagement_ad', full_name='google.ads.googleads.v1.resources.Ad.app_engagement_ad', index=29,
      number=34, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shopping_comparison_listing_ad', full_name='google.ads.googleads.v1.resources.Ad.shopping_comparison_listing_ad', index=30,
      number=36, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ad_data', full_name='google.ads.googleads.v1.resources.Ad.ad_data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=559,
  serialized_end=2874,
)

_AD.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_AD.fields_by_name['final_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AD.fields_by_name['final_app_urls'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_final__app__url__pb2._FINALAPPURL
_AD.fields_by_name['final_mobile_urls'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AD.fields_by_name['tracking_url_template'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AD.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_AD.fields_by_name['display_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AD.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_ad__type__pb2._ADTYPEENUM_ADTYPE
_AD.fields_by_name['added_by_google_ads'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_AD.fields_by_name['device_preference'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_device__pb2._DEVICEENUM_DEVICE
_AD.fields_by_name['url_collections'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_url__collection__pb2._URLCOLLECTION
_AD.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_AD.fields_by_name['system_managed_resource_source'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_system__managed__entity__source__pb2._SYSTEMMANAGEDRESOURCESOURCEENUM_SYSTEMMANAGEDRESOURCESOURCE
_AD.fields_by_name['text_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._TEXTADINFO
_AD.fields_by_name['expanded_text_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._EXPANDEDTEXTADINFO
_AD.fields_by_name['call_only_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._CALLONLYADINFO
_AD.fields_by_name['expanded_dynamic_search_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._EXPANDEDDYNAMICSEARCHADINFO
_AD.fields_by_name['hotel_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._HOTELADINFO
_AD.fields_by_name['shopping_smart_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._SHOPPINGSMARTADINFO
_AD.fields_by_name['shopping_product_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._SHOPPINGPRODUCTADINFO
_AD.fields_by_name['gmail_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._GMAILADINFO
_AD.fields_by_name['image_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._IMAGEADINFO
_AD.fields_by_name['video_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._VIDEOADINFO
_AD.fields_by_name['responsive_search_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._RESPONSIVESEARCHADINFO
_AD.fields_by_name['legacy_responsive_display_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._LEGACYRESPONSIVEDISPLAYADINFO
_AD.fields_by_name['app_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._APPADINFO
_AD.fields_by_name['legacy_app_install_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._LEGACYAPPINSTALLADINFO
_AD.fields_by_name['responsive_display_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._RESPONSIVEDISPLAYADINFO
_AD.fields_by_name['display_upload_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._DISPLAYUPLOADADINFO
_AD.fields_by_name['app_engagement_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._APPENGAGEMENTADINFO
_AD.fields_by_name['shopping_comparison_listing_ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_ad__type__infos__pb2._SHOPPINGCOMPARISONLISTINGADINFO
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['text_ad'])
_AD.fields_by_name['text_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['expanded_text_ad'])
_AD.fields_by_name['expanded_text_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['call_only_ad'])
_AD.fields_by_name['call_only_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['expanded_dynamic_search_ad'])
_AD.fields_by_name['expanded_dynamic_search_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['hotel_ad'])
_AD.fields_by_name['hotel_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['shopping_smart_ad'])
_AD.fields_by_name['shopping_smart_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['shopping_product_ad'])
_AD.fields_by_name['shopping_product_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['gmail_ad'])
_AD.fields_by_name['gmail_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['image_ad'])
_AD.fields_by_name['image_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['video_ad'])
_AD.fields_by_name['video_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['responsive_search_ad'])
_AD.fields_by_name['responsive_search_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['legacy_responsive_display_ad'])
_AD.fields_by_name['legacy_responsive_display_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['app_ad'])
_AD.fields_by_name['app_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['legacy_app_install_ad'])
_AD.fields_by_name['legacy_app_install_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['responsive_display_ad'])
_AD.fields_by_name['responsive_display_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['display_upload_ad'])
_AD.fields_by_name['display_upload_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['app_engagement_ad'])
_AD.fields_by_name['app_engagement_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
_AD.oneofs_by_name['ad_data'].fields.append(
  _AD.fields_by_name['shopping_comparison_listing_ad'])
_AD.fields_by_name['shopping_comparison_listing_ad'].containing_oneof = _AD.oneofs_by_name['ad_data']
DESCRIPTOR.message_types_by_name['Ad'] = _AD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Ad = _reflection.GeneratedProtocolMessageType('Ad', (_message.Message,), dict(
  DESCRIPTOR = _AD,
  __module__ = 'google.ads.googleads_v1.proto.resources.ad_pb2'
  ,
  __doc__ = """An ad.
  
  
  Attributes:
      id:
          The ID of the ad.
      final_urls:
          The list of possible final URLs after all cross-domain
          redirects for the ad.
      final_app_urls:
          A list of final app URLs that will be used on mobile if the
          user has the specific app installed.
      final_mobile_urls:
          The list of possible final mobile URLs after all cross-domain
          redirects for the ad.
      tracking_url_template:
          The URL template for constructing a tracking URL.
      url_custom_parameters:
          The list of mappings that can be used to substitute custom
          parameter tags in a ``tracking_url_template``, ``final_urls``,
          or ``mobile_final_urls``.
      display_url:
          The URL that appears in the ad description for some ad
          formats.
      type:
          The type of ad.
      added_by_google_ads:
          Indicates if this ad was automatically added by Google Ads and
          not by a user. For example, this could happen when ads are
          automatically created as suggestions for new ads based on
          knowledge of how existing ads are performing.
      device_preference:
          The device preference for the ad. You can only specify a
          preference for mobile devices. When this preference is set the
          ad will be preferred over other ads when being displayed on a
          mobile device. The ad can still be displayed on other device
          types, e.g. if no other ads are available. If unspecified (no
          device preference), all devices are targeted. This is only
          supported by some ad types.
      url_collections:
          Additional URLs for the ad that are tagged with a unique
          identifier that can be referenced from other fields in the ad.
      name:
          The name of the ad. This is only used to be able to identify
          the ad. It does not need to be unique and does not affect the
          served ad.
      system_managed_resource_source:
          If this ad is system managed, then this field will indicate
          the source. This field is read-only.
      ad_data:
          Details pertinent to the ad type. Exactly one value must be
          set.
      text_ad:
          Details pertaining to a text ad.
      expanded_text_ad:
          Details pertaining to an expanded text ad.
      call_only_ad:
          Details pertaining to a call-only ad.
      expanded_dynamic_search_ad:
          Details pertaining to an Expanded Dynamic Search Ad. This type
          of ad has its headline, final URLs, and display URL auto-
          generated at serving time according to domain name specific
          information provided by ``dynamic_search_ads_setting`` linked
          at the campaign level.
      hotel_ad:
          Details pertaining to a hotel ad.
      shopping_smart_ad:
          Details pertaining to a Smart Shopping ad.
      shopping_product_ad:
          Details pertaining to a Shopping product ad.
      gmail_ad:
          Details pertaining to a Gmail ad.
      image_ad:
          Details pertaining to an Image ad.
      video_ad:
          Details pertaining to a Video ad.
      responsive_search_ad:
          Details pertaining to a responsive search ad.
      legacy_responsive_display_ad:
          Details pertaining to a legacy responsive display ad.
      app_ad:
          Details pertaining to an app ad.
      legacy_app_install_ad:
          Details pertaining to a legacy app install ad.
      responsive_display_ad:
          Details pertaining to a responsive display ad.
      display_upload_ad:
          Details pertaining to a display upload ad.
      app_engagement_ad:
          Details pertaining to an app engagement ad.
      shopping_comparison_listing_ad:
          Details pertaining to a Shopping Comparison Listing ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.Ad)
  ))
_sym_db.RegisterMessage(Ad)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import google.api_core.grpc_helpers

from google.ads.google_ads.v1.proto.services import payments_account_service_pb2_grpc


class PaymentsAccountServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.ads.googleads.v1.services PaymentsAccountService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """
    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ()

    def __init__(self,
                 channel=None,
                 credentials=None,
                 address='googleads.googleapis.com:443'):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                'The `channel` and `credentials` arguments are mutually '
                'exclusive.', )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            'payments_account_service_stub': payments_account_service_pb2_grpc.PaymentsAccountServiceStub(channel),
        }


    @classmethod
    def create_channel(
                cls,
                address='googleads.googleapis.com:443',
                credentials=None,
                **kwargs):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address,
            credentials=credentials,
            scopes=cls._OAUTH_SCOPES,
            **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def list_payments_accounts(self):
        """Return the gRPC stub for :meth:`PaymentsAccountServiceClient.list_payments_accounts`.

        Returns all Payments accounts associated with all managers
        between the login customer ID and specified serving customer in the
        hierarchy, inclusive.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'payments_account_service_stub'].ListPaymentsAccounts



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/customer_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import access_role_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_access__role__pb2
from google.ads.google_ads.v2.proto.resources import customer_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/customer_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\024CustomerServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\n=google/ads/googleads_v2/proto/services/customer_service.proto\x12 google.ads.googleads.v2.services\x1a\x35google/ads/googleads_v2/proto/enums/access_role.proto\x1a\x36google/ads/googleads_v2/proto/resources/customer.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/api/client.proto\"+\n\x12GetCustomerRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x8b\x01\n\x15MutateCustomerRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x46\n\toperation\x18\x04 \x01(\x0b\x32\x33.google.ads.googleads.v2.services.CustomerOperation\x12\x15\n\rvalidate_only\x18\x05 \x01(\x08\"\xfc\x01\n\x1b\x43reateCustomerClientRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x44\n\x0f\x63ustomer_client\x18\x02 \x01(\x0b\x32+.google.ads.googleads.v2.resources.Customer\x12\x33\n\remail_address\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12M\n\x0b\x61\x63\x63\x65ss_role\x18\x04 \x01(\x0e\x32\x38.google.ads.googleads.v2.enums.AccessRoleEnum.AccessRole\"\x81\x01\n\x11\x43ustomerOperation\x12;\n\x06update\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v2.resources.Customer\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"5\n\x1c\x43reateCustomerClientResponse\x12\x15\n\rresource_name\x18\x02 \x01(\t\"`\n\x16MutateCustomerResponse\x12\x46\n\x06result\x18\x02 \x01(\x0b\x32\x36.google.ads.googleads.v2.services.MutateCustomerResult\"-\n\x14MutateCustomerResult\x12\x15\n\rresource_name\x18\x01 \x01(\t\" \n\x1eListAccessibleCustomersRequest\"9\n\x1fListAccessibleCustomersResponse\x12\x16\n\x0eresource_names\x18\x01 \x03(\t2\xa8\x06\n\x0f\x43ustomerService\x12\x99\x01\n\x0bGetCustomer\x12\x34.google.ads.googleads.v2.services.GetCustomerRequest\x1a+.google.ads.googleads.v2.resources.Customer\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v2/{resource_name=customers/*}\x12\xb4\x01\n\x0eMutateCustomer\x12\x37.google.ads.googleads.v2.services.MutateCustomerRequest\x1a\x38.google.ads.googleads.v2.services.MutateCustomerResponse\"/\x82\xd3\xe4\x93\x02)\"$/v2/customers/{customer_id=*}:mutate:\x01*\x12\xcd\x01\n\x17ListAccessibleCustomers\x12@.google.ads.googleads.v2.services.ListAccessibleCustomersRequest\x1a\x41.google.ads.googleads.v2.services.ListAccessibleCustomersResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/v2/customers:listAccessibleCustomers\x12\xd4\x01\n\x14\x43reateCustomerClient\x12=.google.ads.googleads.v2.services.CreateCustomerClientRequest\x1a>.google.ads.googleads.v2.services.CreateCustomerClientResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v2/customers/{customer_id=*}:createCustomerClient:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\xfb\x01\n$com.google.ads.googleads.v2.servicesB\x14\x43ustomerServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_access__role__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETCUSTOMERREQUEST = _descriptor.Descriptor(
  name='GetCustomerRequest',
  full_name='google.ads.googleads.v2.services.GetCustomerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetCustomerRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=331,
  serialized_end=374,
)


_MUTATECUSTOMERREQUEST = _descriptor.Descriptor(
  name='MutateCustomerRequest',
  full_name='google.ads.googleads.v2.services.MutateCustomerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateCustomerRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.MutateCustomerRequest.operation', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateCustomerRequest.validate_only', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=516,
)


_CREATECUSTOMERCLIENTREQUEST = _descriptor.Descriptor(
  name='CreateCustomerClientRequest',
  full_name='google.ads.googleads.v2.services.CreateCustomerClientRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.CreateCustomerClientRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_client', full_name='google.ads.googleads.v2.services.CreateCustomerClientRequest.customer_client', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email_address', full_name='google.ads.googleads.v2.services.CreateCustomerClientRequest.email_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_role', full_name='google.ads.googleads.v2.services.CreateCustomerClientRequest.access_role', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=771,
)


_CUSTOMEROPERATION = _descriptor.Descriptor(
  name='CustomerOperation',
  full_name='google.ads.googleads.v2.services.CustomerOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v2.services.CustomerOperation.update', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v2.services.CustomerOperation.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=903,
)


_CREATECUSTOMERCLIENTRESPONSE = _descriptor.Descriptor(
  name='CreateCustomerClientResponse',
  full_name='google.ads.googleads.v2.services.CreateCustomerClientResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.CreateCustomerClientResponse.resource_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=958,
)


_MUTATECUSTOMERRESPONSE = _descriptor.Descriptor(
  name='MutateCustomerResponse',
  full_name='google.ads.googleads.v2.services.MutateCustomerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='google.ads.googleads.v2.services.MutateCustomerResponse.result', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=960,
  serialized_end=1056,
)


_MUTATECUSTOMERRESULT = _descriptor.Descriptor(
  name='MutateCustomerResult',
  full_name='google.ads.googleads.v2.services.MutateCustomerResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateCustomerResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1058,
  serialized_end=1103,
)


_LISTACCESSIBLECUSTOMERSREQUEST = _descriptor.Descriptor(
  name='ListAccessibleCustomersRequest',
  full_name='google.ads.googleads.v2.services.ListAccessibleCustomersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1105,
  serialized_end=1137,
)


_LISTACCESSIBLECUSTOMERSRESPONSE = _descriptor.Descriptor(
  name='ListAccessibleCustomersResponse',
  full_name='google.ads.googleads.v2.services.ListAccessibleCustomersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_names', full_name='google.ads.googleads.v2.services.ListAccessibleCustomersResponse.resource_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1139,
  serialized_end=1196,
)

_MUTATECUSTOMERREQUEST.fields_by_name['operation'].message_type = _CUSTOMEROPERATION
_CREATECUSTOMERCLIENTREQUEST.fields_by_name['customer_client'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2._CUSTOMER
_CREATECUSTOMERCLIENTREQUEST.fields_by_name['email_address'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CREATECUSTOMERCLIENTREQUEST.fields_by_name['access_role'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_access__role__pb2._ACCESSROLEENUM_ACCESSROLE
_CUSTOMEROPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2._CUSTOMER
_CUSTOMEROPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_MUTATECUSTOMERRESPONSE.fields_by_name['result'].message_type = _MUTATECUSTOMERRESULT
DESCRIPTOR.message_types_by_name['GetCustomerRequest'] = _GETCUSTOMERREQUEST
DESCRIPTOR.message_types_by_name['MutateCustomerRequest'] = _MUTATECUSTOMERREQUEST
DESCRIPTOR.message_types_by_name['CreateCustomerClientRequest'] = _CREATECUSTOMERCLIENTREQUEST
DESCRIPTOR.message_types_by_name['CustomerOperation'] = _CUSTOMEROPERATION
DESCRIPTOR.message_types_by_name['CreateCustomerClientResponse'] = _CREATECUSTOMERCLIENTRESPONSE
DESCRIPTOR.message_types_by_name['MutateCustomerResponse'] = _MUTATECUSTOMERRESPONSE
DESCRIPTOR.message_types_by_name['MutateCustomerResult'] = _MUTATECUSTOMERRESULT
DESCRIPTOR.message_types_by_name['ListAccessibleCustomersRequest'] = _LISTACCESSIBLECUSTOMERSREQUEST
DESCRIPTOR.message_types_by_name['ListAccessibleCustomersResponse'] = _LISTACCESSIBLECUSTOMERSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCustomerRequest = _reflection.GeneratedProtocolMessageType('GetCustomerRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCUSTOMERREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerService.GetCustomer][google.ads.googleads.v2.services.CustomerService.GetCustomer].
  
  
  Attributes:
      resource_name:
          The resource name of the customer to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetCustomerRequest)
  ))
_sym_db.RegisterMessage(GetCustomerRequest)

MutateCustomerRequest = _reflection.GeneratedProtocolMessageType('MutateCustomerRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerService.MutateCustomer][google.ads.googleads.v2.services.CustomerService.MutateCustomer].
  
  
  Attributes:
      customer_id:
          The ID of the customer being modified.
      operation:
          The operation to perform on the customer
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateCustomerRequest)
  ))
_sym_db.RegisterMessage(MutateCustomerRequest)

CreateCustomerClientRequest = _reflection.GeneratedProtocolMessageType('CreateCustomerClientRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATECUSTOMERCLIENTREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerService.CreateCustomerClient][google.ads.googleads.v2.services.CustomerService.CreateCustomerClient].
  
  
  Attributes:
      customer_id:
          The ID of the Manager under whom client customer is being
          created.
      customer_client:
          The new client customer to create. The resource name on this
          customer will be ignored.
      email_address:
          Email address of the user who should be invited on the created
          client customer. Accessible to whitelisted customers only.
      access_role:
          The proposed role of user on the created client customer.
          Accessible to whitelisted customers only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.CreateCustomerClientRequest)
  ))
_sym_db.RegisterMessage(CreateCustomerClientRequest)

CustomerOperation = _reflection.GeneratedProtocolMessageType('CustomerOperation', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMEROPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """A single update on a customer.
  
  
  Attributes:
      update:
          Mutate operation. Only updates are supported for customer.
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.CustomerOperation)
  ))
_sym_db.RegisterMessage(CustomerOperation)

CreateCustomerClientResponse = _reflection.GeneratedProtocolMessageType('CreateCustomerClientResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATECUSTOMERCLIENTRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """Response message for CreateCustomerClient mutate.
  
  
  Attributes:
      resource_name:
          The resource name of the newly created customer client.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.CreateCustomerClientResponse)
  ))
_sym_db.RegisterMessage(CreateCustomerClientResponse)

MutateCustomerResponse = _reflection.GeneratedProtocolMessageType('MutateCustomerResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """Response message for customer mutate.
  
  
  Attributes:
      result:
          Result for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateCustomerResponse)
  ))
_sym_db.RegisterMessage(MutateCustomerResponse)

MutateCustomerResult = _reflection.GeneratedProtocolMessageType('MutateCustomerResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECUSTOMERRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """The result for the customer mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateCustomerResult)
  ))
_sym_db.RegisterMessage(MutateCustomerResult)

ListAccessibleCustomersRequest = _reflection.GeneratedProtocolMessageType('ListAccessibleCustomersRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTACCESSIBLECUSTOMERSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerService.ListAccessibleCustomers][google.ads.googleads.v2.services.CustomerService.ListAccessibleCustomers].
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListAccessibleCustomersRequest)
  ))
_sym_db.RegisterMessage(ListAccessibleCustomersRequest)

ListAccessibleCustomersResponse = _reflection.GeneratedProtocolMessageType('ListAccessibleCustomersResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTACCESSIBLECUSTOMERSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.customer_service_pb2'
  ,
  __doc__ = """Response message for
  [CustomerService.ListAccessibleCustomers][google.ads.googleads.v2.services.CustomerService.ListAccessibleCustomers].
  
  
  Attributes:
      resource_names:
          Resource name of customers directly accessible by the user
          authenticating the call.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.ListAccessibleCustomersResponse)
  ))
_sym_db.RegisterMessage(ListAccessibleCustomersResponse)


DESCRIPTOR._options = None

_CUSTOMERSERVICE = _descriptor.ServiceDescriptor(
  name='CustomerService',
  full_name='google.ads.googleads.v2.services.CustomerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=1199,
  serialized_end=2007,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCustomer',
    full_name='google.ads.googleads.v2.services.CustomerService.GetCustomer',
    index=0,
    containing_service=None,
    input_type=_GETCUSTOMERREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_customer__pb2._CUSTOMER,
    serialized_options=_b('\202\323\344\223\002!\022\037/v2/{resource_name=customers/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCustomer',
    full_name='google.ads.googleads.v2.services.CustomerService.MutateCustomer',
    index=1,
    containing_service=None,
    input_type=_MUTATECUSTOMERREQUEST,
    output_type=_MUTATECUSTOMERRESPONSE,
    serialized_options=_b('\202\323\344\223\002)\"$/v2/customers/{customer_id=*}:mutate:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessibleCustomers',
    full_name='google.ads.googleads.v2.services.CustomerService.ListAccessibleCustomers',
    index=2,
    containing_service=None,
    input_type=_LISTACCESSIBLECUSTOMERSREQUEST,
    output_type=_LISTACCESSIBLECUSTOMERSRESPONSE,
    serialized_options=_b('\202\323\344\223\002\'\022%/v2/customers:listAccessibleCustomers'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateCustomerClient',
    full_name='google.ads.googleads.v2.services.CustomerService.CreateCustomerClient',
    index=3,
    containing_service=None,
    input_type=_CREATECUSTOMERCLIENTREQUEST,
    output_type=_CREATECUSTOMERCLIENTRESPONSE,
    serialized_options=_b('\202\323\344\223\0027\"2/v2/customers/{customer_id=*}:createCustomerClient:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CUSTOMERSERVICE)

DESCRIPTOR.services_by_name['CustomerService'] = _CUSTOMERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/keyword_plan_competition_level.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/keyword_plan_competition_level.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB KeywordPlanCompetitionLevelProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\nHgoogle/ads/googleads_v1/proto/enums/keyword_plan_competition_level.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"}\n\x1fKeywordPlanCompetitionLevelEnum\"Z\n\x1bKeywordPlanCompetitionLevel\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x07\n\x03LOW\x10\x02\x12\n\n\x06MEDIUM\x10\x03\x12\x08\n\x04HIGH\x10\x04\x42\xf5\x01\n!com.google.ads.googleads.v1.enumsB KeywordPlanCompetitionLevelProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_KEYWORDPLANCOMPETITIONLEVELENUM_KEYWORDPLANCOMPETITIONLEVEL = _descriptor.EnumDescriptor(
  name='KeywordPlanCompetitionLevel',
  full_name='google.ads.googleads.v1.enums.KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOW', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=172,
  serialized_end=262,
)
_sym_db.RegisterEnumDescriptor(_KEYWORDPLANCOMPETITIONLEVELENUM_KEYWORDPLANCOMPETITIONLEVEL)


_KEYWORDPLANCOMPETITIONLEVELENUM = _descriptor.Descriptor(
  name='KeywordPlanCompetitionLevelEnum',
  full_name='google.ads.googleads.v1.enums.KeywordPlanCompetitionLevelEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KEYWORDPLANCOMPETITIONLEVELENUM_KEYWORDPLANCOMPETITIONLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=262,
)

_KEYWORDPLANCOMPETITIONLEVELENUM_KEYWORDPLANCOMPETITIONLEVEL.containing_type = _KEYWORDPLANCOMPETITIONLEVELENUM
DESCRIPTOR.message_types_by_name['KeywordPlanCompetitionLevelEnum'] = _KEYWORDPLANCOMPETITIONLEVELENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanCompetitionLevelEnum = _reflection.GeneratedProtocolMessageType('KeywordPlanCompetitionLevelEnum', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANCOMPETITIONLEVELENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.keyword_plan_competition_level_pb2'
  ,
  __doc__ = """Container for enumeration of keyword competition levels. The competition
  level indicates how competitive ad placement is for a keyword and is
  determined by the number of advertisers bidding on that keyword relative
  to all keywords across Google. The competition level can depend on the
  location and Search Network targeting options you've selected.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.KeywordPlanCompetitionLevelEnum)
  ))
_sym_db.RegisterMessage(KeywordPlanCompetitionLevelEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/asset_types.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import mime_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/asset_types.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\017AssetTypesProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n6google/ads/googleads_v2/proto/common/asset_types.proto\x12\x1egoogle.ads.googleads.v2.common\x1a\x33google/ads/googleads_v2/proto/enums/mime_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"K\n\x11YoutubeVideoAsset\x12\x36\n\x10youtube_video_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"=\n\x10MediaBundleAsset\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValue\"\xf3\x01\n\nImageAsset\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValue\x12.\n\tfile_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12G\n\tmime_type\x18\x03 \x01(\x0e\x32\x34.google.ads.googleads.v2.enums.MimeTypeEnum.MimeType\x12\x41\n\tfull_size\x18\x04 \x01(\x0b\x32..google.ads.googleads.v2.common.ImageDimension\"\xa2\x01\n\x0eImageDimension\x12\x32\n\rheight_pixels\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cwidth_pixels\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12)\n\x03url\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"7\n\tTextAsset\x12*\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xea\x01\n\"com.google.ads.googleads.v2.commonB\x0f\x41ssetTypesProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_YOUTUBEVIDEOASSET = _descriptor.Descriptor(
  name='YoutubeVideoAsset',
  full_name='google.ads.googleads.v2.common.YoutubeVideoAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='youtube_video_id', full_name='google.ads.googleads.v2.common.YoutubeVideoAsset.youtube_video_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=280,
)


_MEDIABUNDLEASSET = _descriptor.Descriptor(
  name='MediaBundleAsset',
  full_name='google.ads.googleads.v2.common.MediaBundleAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='google.ads.googleads.v2.common.MediaBundleAsset.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=343,
)


_IMAGEASSET = _descriptor.Descriptor(
  name='ImageAsset',
  full_name='google.ads.googleads.v2.common.ImageAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='google.ads.googleads.v2.common.ImageAsset.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='google.ads.googleads.v2.common.ImageAsset.file_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='google.ads.googleads.v2.common.ImageAsset.mime_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_size', full_name='google.ads.googleads.v2.common.ImageAsset.full_size', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=589,
)


_IMAGEDIMENSION = _descriptor.Descriptor(
  name='ImageDimension',
  full_name='google.ads.googleads.v2.common.ImageDimension',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='height_pixels', full_name='google.ads.googleads.v2.common.ImageDimension.height_pixels', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='width_pixels', full_name='google.ads.googleads.v2.common.ImageDimension.width_pixels', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='google.ads.googleads.v2.common.ImageDimension.url', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=754,
)


_TEXTASSET = _descriptor.Descriptor(
  name='TextAsset',
  full_name='google.ads.googleads.v2.common.TextAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v2.common.TextAsset.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=811,
)

_YOUTUBEVIDEOASSET.fields_by_name['youtube_video_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MEDIABUNDLEASSET.fields_by_name['data'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_IMAGEASSET.fields_by_name['data'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_IMAGEASSET.fields_by_name['file_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEASSET.fields_by_name['mime_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2._MIMETYPEENUM_MIMETYPE
_IMAGEASSET.fields_by_name['full_size'].message_type = _IMAGEDIMENSION
_IMAGEDIMENSION.fields_by_name['height_pixels'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEDIMENSION.fields_by_name['width_pixels'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEDIMENSION.fields_by_name['url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTASSET.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['YoutubeVideoAsset'] = _YOUTUBEVIDEOASSET
DESCRIPTOR.message_types_by_name['MediaBundleAsset'] = _MEDIABUNDLEASSET
DESCRIPTOR.message_types_by_name['ImageAsset'] = _IMAGEASSET
DESCRIPTOR.message_types_by_name['ImageDimension'] = _IMAGEDIMENSION
DESCRIPTOR.message_types_by_name['TextAsset'] = _TEXTASSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

YoutubeVideoAsset = _reflection.GeneratedProtocolMessageType('YoutubeVideoAsset', (_message.Message,), dict(
  DESCRIPTOR = _YOUTUBEVIDEOASSET,
  __module__ = 'google.ads.googleads_v2.proto.common.asset_types_pb2'
  ,
  __doc__ = """A YouTube asset.
  
  
  Attributes:
      youtube_video_id:
          YouTube video id. This is the 11 character string value used
          in the YouTube video URL.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.YoutubeVideoAsset)
  ))
_sym_db.RegisterMessage(YoutubeVideoAsset)

MediaBundleAsset = _reflection.GeneratedProtocolMessageType('MediaBundleAsset', (_message.Message,), dict(
  DESCRIPTOR = _MEDIABUNDLEASSET,
  __module__ = 'google.ads.googleads_v2.proto.common.asset_types_pb2'
  ,
  __doc__ = """A MediaBundle asset.
  
  
  Attributes:
      data:
          Media bundle (ZIP file) asset data. The format of the uploaded
          ZIP file depends on the ad field where it will be used. For
          more information on the format, see the documentation of the
          ad field where you plan on using the MediaBundleAsset. This
          field is mutate only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.MediaBundleAsset)
  ))
_sym_db.RegisterMessage(MediaBundleAsset)

ImageAsset = _reflection.GeneratedProtocolMessageType('ImageAsset', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEASSET,
  __module__ = 'google.ads.googleads_v2.proto.common.asset_types_pb2'
  ,
  __doc__ = """An Image asset.
  
  
  Attributes:
      data:
          The raw bytes data of an image. This field is mutate only.
      file_size:
          File size of the image asset in bytes.
      mime_type:
          MIME type of the image asset.
      full_size:
          Metadata for this image at its original size.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ImageAsset)
  ))
_sym_db.RegisterMessage(ImageAsset)

ImageDimension = _reflection.GeneratedProtocolMessageType('ImageDimension', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEDIMENSION,
  __module__ = 'google.ads.googleads_v2.proto.common.asset_types_pb2'
  ,
  __doc__ = """Metadata for an image at a certain size, either original or resized.
  
  
  Attributes:
      height_pixels:
          Height of the image.
      width_pixels:
          Width of the image.
      url:
          A URL that returns the image with this height and width.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.ImageDimension)
  ))
_sym_db.RegisterMessage(ImageDimension)

TextAsset = _reflection.GeneratedProtocolMessageType('TextAsset', (_message.Message,), dict(
  DESCRIPTOR = _TEXTASSET,
  __module__ = 'google.ads.googleads_v2.proto.common.asset_types_pb2'
  ,
  __doc__ = """A Text asset.
  
  
  Attributes:
      text:
          Text content of the text asset.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.TextAsset)
  ))
_sym_db.RegisterMessage(TextAsset)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Accesses the google.ads.googleads.v2.services CampaignExperimentService API."""

import functools
import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.gapic_v1.routing_header
import google.api_core.grpc_helpers
import google.api_core.operation
import google.api_core.operations_v1
import google.api_core.page_iterator
import google.api_core.path_template
import grpc

from google.ads.google_ads.v2.services import campaign_experiment_service_client_config
from google.ads.google_ads.v2.services import enums
from google.ads.google_ads.v2.services.transports import campaign_experiment_service_grpc_transport
from google.ads.google_ads.v2.proto.resources import account_budget_pb2
from google.ads.google_ads.v2.proto.resources import account_budget_proposal_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_ad_asset_view_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_ad_label_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_ad_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_audience_view_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_bid_modifier_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_criterion_label_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_criterion_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_criterion_simulation_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_extension_setting_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_feed_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_label_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_pb2
from google.ads.google_ads.v2.proto.resources import ad_group_simulation_pb2
from google.ads.google_ads.v2.proto.resources import ad_parameter_pb2
from google.ads.google_ads.v2.proto.resources import ad_pb2
from google.ads.google_ads.v2.proto.resources import ad_schedule_view_pb2
from google.ads.google_ads.v2.proto.resources import age_range_view_pb2
from google.ads.google_ads.v2.proto.resources import asset_pb2
from google.ads.google_ads.v2.proto.resources import bidding_strategy_pb2
from google.ads.google_ads.v2.proto.resources import billing_setup_pb2
from google.ads.google_ads.v2.proto.resources import campaign_audience_view_pb2
from google.ads.google_ads.v2.proto.resources import campaign_bid_modifier_pb2
from google.ads.google_ads.v2.proto.resources import campaign_budget_pb2
from google.ads.google_ads.v2.proto.resources import campaign_criterion_pb2
from google.ads.google_ads.v2.proto.resources import campaign_criterion_simulation_pb2
from google.ads.google_ads.v2.proto.resources import campaign_draft_pb2
from google.ads.google_ads.v2.proto.resources import campaign_experiment_pb2
from google.ads.google_ads.v2.proto.services import account_budget_proposal_service_pb2
from google.ads.google_ads.v2.proto.services import account_budget_proposal_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import account_budget_service_pb2
from google.ads.google_ads.v2.proto.services import account_budget_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_ad_asset_view_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_ad_asset_view_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_ad_label_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_ad_label_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_ad_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_ad_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_audience_view_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_audience_view_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_bid_modifier_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_bid_modifier_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_criterion_label_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_criterion_label_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_criterion_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_criterion_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_criterion_simulation_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_criterion_simulation_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_extension_setting_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_extension_setting_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_feed_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_feed_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_label_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_label_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_group_simulation_service_pb2
from google.ads.google_ads.v2.proto.services import ad_group_simulation_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_parameter_service_pb2
from google.ads.google_ads.v2.proto.services import ad_parameter_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_schedule_view_service_pb2
from google.ads.google_ads.v2.proto.services import ad_schedule_view_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import ad_service_pb2
from google.ads.google_ads.v2.proto.services import ad_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import age_range_view_service_pb2
from google.ads.google_ads.v2.proto.services import age_range_view_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import asset_service_pb2
from google.ads.google_ads.v2.proto.services import asset_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import bidding_strategy_service_pb2
from google.ads.google_ads.v2.proto.services import bidding_strategy_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import billing_setup_service_pb2
from google.ads.google_ads.v2.proto.services import billing_setup_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import campaign_audience_view_service_pb2
from google.ads.google_ads.v2.proto.services import campaign_audience_view_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import campaign_bid_modifier_service_pb2
from google.ads.google_ads.v2.proto.services import campaign_bid_modifier_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import campaign_budget_service_pb2
from google.ads.google_ads.v2.proto.services import campaign_budget_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import campaign_criterion_service_pb2
from google.ads.google_ads.v2.proto.services import campaign_criterion_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import campaign_criterion_simulation_service_pb2
from google.ads.google_ads.v2.proto.services import campaign_criterion_simulation_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import campaign_draft_service_pb2
from google.ads.google_ads.v2.proto.services import campaign_draft_service_pb2_grpc
from google.ads.google_ads.v2.proto.services import campaign_experiment_service_pb2
from google.ads.google_ads.v2.proto.services import campaign_experiment_service_pb2_grpc
from google.longrunning import operations_pb2
from google.protobuf import empty_pb2



_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
    'google-ads',
).version


class CampaignExperimentServiceClient(object):
    """
    CampaignExperimentService manages the life cycle of campaign experiments.
    It is used to create new experiments from drafts, modify experiment
    properties, promote changes in an experiment back to its base campaign,
    graduate experiments into new stand-alone campaigns, and to remove an
    experiment.

    An experiment consists of two variants or arms - the base campaign and the
    experiment campaign, directing a fixed share of traffic to each arm.
    A campaign experiment is created from a draft of changes to the base campaign
    and will be a snapshot of changes in the draft at the time of creation.
    """

    SERVICE_ADDRESS = 'googleads.googleapis.com:443'
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = 'google.ads.googleads.v2.services.CampaignExperimentService'


    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            CampaignExperimentServiceClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(
            filename)
        kwargs['credentials'] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file


    @classmethod
    def campaign_experiment_path(cls, customer, campaign_experiment):
        """Return a fully-qualified campaign_experiment string."""
        return google.api_core.path_template.expand(
            'customers/{customer}/campaignExperiments/{campaign_experiment}',
            customer=customer,
            campaign_experiment=campaign_experiment,
        )

    def __init__(self, transport=None, channel=None, credentials=None,
            client_config=None, client_info=None):
        """Constructor.

        Args:
            transport (Union[~.CampaignExperimentServiceGrpcTransport,
                    Callable[[~.Credentials, type], ~.CampaignExperimentServiceGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn('The `client_config` argument is deprecated.',
                          PendingDeprecationWarning, stacklevel=2)
        else:
            client_config = campaign_experiment_service_client_config.config

        if channel:
            warnings.warn('The `channel` argument is deprecated; use '
                          '`transport` instead.',
                          PendingDeprecationWarning, stacklevel=2)

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=campaign_experiment_service_grpc_transport.CampaignExperimentServiceGrpcTransport,
                )
            else:
                if credentials:
                    raise ValueError(
                        'Received both a transport instance and '
                        'credentials; these are mutually exclusive.'
                    )
                self.transport = transport
        else:
            self.transport = campaign_experiment_service_grpc_transport.CampaignExperimentServiceGrpcTransport(
                address=self.SERVICE_ADDRESS,
                channel=channel,
                credentials=credentials,
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION,
            )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config['interfaces'][self._INTERFACE_NAME],
        )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def get_campaign_experiment(
            self,
            resource_name,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Returns the requested campaign experiment in full detail.

        Args:
            resource_name (str): The resource name of the campaign experiment to fetch.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v2.types.CampaignExperiment` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'get_campaign_experiment' not in self._inner_api_calls:
            self._inner_api_calls['get_campaign_experiment'] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_campaign_experiment,
                default_retry=self._method_configs['GetCampaignExperiment'].retry,
                default_timeout=self._method_configs['GetCampaignExperiment'].timeout,
                client_info=self._client_info,
            )

        request = campaign_experiment_service_pb2.GetCampaignExperimentRequest(
            resource_name=resource_name,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [('resource_name', resource_name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(routing_header)
            metadata.append(routing_metadata)

        return self._inner_api_calls['get_campaign_experiment'](request, retry=retry, timeout=timeout, metadata=metadata)

    def create_campaign_experiment(
            self,
            customer_id,
            campaign_experiment,
            validate_only=None,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Creates a campaign experiment based on a campaign draft. The draft campaign
        will be forked into a real campaign (called the experiment campaign) that
        will begin serving ads if successfully created.

        The campaign experiment is created immediately with status INITIALIZING.
        This method return a long running operation that tracks the forking of the
        draft campaign. If the forking fails, a list of errors can be retrieved
        using the ListCampaignExperimentAsyncErrors method. The operation's
        metadata will be a StringValue containing the resource name of the created
        campaign experiment.

        Args:
            customer_id (str): The ID of the customer whose campaign experiment is being created.
            campaign_experiment (Union[dict, ~google.ads.googleads_v2.types.CampaignExperiment]): The campaign experiment to be created.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.ads.googleads_v2.types.CampaignExperiment`
            validate_only (bool): If true, the request is validated but not executed. Only errors are
                returned, not results.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v2.types._OperationFuture` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'create_campaign_experiment' not in self._inner_api_calls:
            self._inner_api_calls['create_campaign_experiment'] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.create_campaign_experiment,
                default_retry=self._method_configs['CreateCampaignExperiment'].retry,
                default_timeout=self._method_configs['CreateCampaignExperiment'].timeout,
                client_info=self._client_info,
            )

        request = campaign_experiment_service_pb2.CreateCampaignExperimentRequest(
            customer_id=customer_id,
            campaign_experiment=campaign_experiment,
            validate_only=validate_only,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [('customer_id', customer_id)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(routing_header)
            metadata.append(routing_metadata)

        operation = self._inner_api_calls['create_campaign_experiment'](request, retry=retry, timeout=timeout, metadata=metadata)
        return google.api_core.operation.from_gapic(
            operation,
            self.transport._operations_client,
            empty_pb2.Empty,
            metadata_type=campaign_experiment_service_pb2.CreateCampaignExperimentMetadata,
        )

    def mutate_campaign_experiments(
            self,
            customer_id,
            operations,
            partial_failure=None,
            validate_only=None,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Updates campaign experiments. Operation statuses are returned.

        Args:
            customer_id (str): The ID of the customer whose campaign experiments are being modified.
            operations (list[Union[dict, ~google.ads.googleads_v2.types.CampaignExperimentOperation]]): The list of operations to perform on individual campaign experiments.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.ads.googleads_v2.types.CampaignExperimentOperation`
            partial_failure (bool): If true, successful operations will be carried out and invalid
                operations will return errors. If false, all operations will be carried
                out in one transaction if and only if they are all valid.
                Default is false.
            validate_only (bool): If true, the request is validated but not executed. Only errors are
                returned, not results.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v2.types.MutateCampaignExperimentsResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'mutate_campaign_experiments' not in self._inner_api_calls:
            self._inner_api_calls['mutate_campaign_experiments'] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.mutate_campaign_experiments,
                default_retry=self._method_configs['MutateCampaignExperiments'].retry,
                default_timeout=self._method_configs['MutateCampaignExperiments'].timeout,
                client_info=self._client_info,
            )

        request = campaign_experiment_service_pb2.MutateCampaignExperimentsRequest(
            customer_id=customer_id,
            operations=operations,
            partial_failure=partial_failure,
            validate_only=validate_only,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [('customer_id', customer_id)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(routing_header)
            metadata.append(routing_metadata)

        return self._inner_api_calls['mutate_campaign_experiments'](request, retry=retry, timeout=timeout, metadata=metadata)

    def graduate_campaign_experiment(
            self,
            campaign_experiment,
            campaign_budget,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Graduates a campaign experiment to a full campaign. The base and experiment
        campaigns will start running independently with their own budgets.

        Args:
            campaign_experiment (str): The resource name of the campaign experiment to graduate.
            campaign_budget (str): Resource name of the budget to attach to the campaign graduated from the
                experiment.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v2.types.GraduateCampaignExperimentResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'graduate_campaign_experiment' not in self._inner_api_calls:
            self._inner_api_calls['graduate_campaign_experiment'] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.graduate_campaign_experiment,
                default_retry=self._method_configs['GraduateCampaignExperiment'].retry,
                default_timeout=self._method_configs['GraduateCampaignExperiment'].timeout,
                client_info=self._client_info,
            )

        request = campaign_experiment_service_pb2.GraduateCampaignExperimentRequest(
            campaign_experiment=campaign_experiment,
            campaign_budget=campaign_budget,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [('campaign_experiment', campaign_experiment)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(routing_header)
            metadata.append(routing_metadata)

        return self._inner_api_calls['graduate_campaign_experiment'](request, retry=retry, timeout=timeout, metadata=metadata)

    def promote_campaign_experiment(
            self,
            campaign_experiment,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Promotes the changes in a experiment campaign back to the base campaign.

        The campaign experiment is updated immediately with status PROMOTING.
        This method return a long running operation that tracks the promoting of
        the experiment campaign. If the promoting fails, a list of errors can be
        retrieved using the ListCampaignExperimentAsyncErrors method.

        Args:
            campaign_experiment (str): The resource name of the campaign experiment to promote.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v2.types._OperationFuture` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'promote_campaign_experiment' not in self._inner_api_calls:
            self._inner_api_calls['promote_campaign_experiment'] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.promote_campaign_experiment,
                default_retry=self._method_configs['PromoteCampaignExperiment'].retry,
                default_timeout=self._method_configs['PromoteCampaignExperiment'].timeout,
                client_info=self._client_info,
            )

        request = campaign_experiment_service_pb2.PromoteCampaignExperimentRequest(
            campaign_experiment=campaign_experiment,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [('campaign_experiment', campaign_experiment)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(routing_header)
            metadata.append(routing_metadata)

        operation = self._inner_api_calls['promote_campaign_experiment'](request, retry=retry, timeout=timeout, metadata=metadata)
        return google.api_core.operation.from_gapic(
            operation,
            self.transport._operations_client,
            empty_pb2.Empty,
            metadata_type=empty_pb2.Empty,
        )

    def end_campaign_experiment(
            self,
            campaign_experiment,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Immediately ends a campaign experiment, changing the experiment's scheduled
        end date and without waiting for end of day. End date is updated to be the
        time of the request.

        Args:
            campaign_experiment (str): The resource name of the campaign experiment to end.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'end_campaign_experiment' not in self._inner_api_calls:
            self._inner_api_calls['end_campaign_experiment'] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.end_campaign_experiment,
                default_retry=self._method_configs['EndCampaignExperiment'].retry,
                default_timeout=self._method_configs['EndCampaignExperiment'].timeout,
                client_info=self._client_info,
            )

        request = campaign_experiment_service_pb2.EndCampaignExperimentRequest(
            campaign_experiment=campaign_experiment,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [('campaign_experiment', campaign_experiment)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(routing_header)
            metadata.append(routing_metadata)

        self._inner_api_calls['end_campaign_experiment'](request, retry=retry, timeout=timeout, metadata=metadata)

    def list_campaign_experiment_async_errors(
            self,
            resource_name,
            page_size=None,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Returns all errors that occurred during CampaignExperiment create or
        promote (whichever occurred last).
        Supports standard list paging.

        Args:
            resource_name (str): The name of the campaign experiment from which to retrieve the async
                errors.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.gax.PageIterator` instance. By default, this
            is an iterable of :class:`~google.ads.googleads_v2.types.Status` instances.
            This object can also be configured to iterate over the pages
            of the response through the `options` parameter.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'list_campaign_experiment_async_errors' not in self._inner_api_calls:
            self._inner_api_calls['list_campaign_experiment_async_errors'] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_campaign_experiment_async_errors,
                default_retry=self._method_configs['ListCampaignExperimentAsyncErrors'].retry,
                default_timeout=self._method_configs['ListCampaignExperimentAsyncErrors'].timeout,
                client_info=self._client_info,
            )

        request = campaign_experiment_service_pb2.ListCampaignExperimentAsyncErrorsRequest(
            resource_name=resource_name,
            page_size=page_size,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [('resource_name', resource_name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(routing_header)
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(self._inner_api_calls['list_campaign_experiment_async_errors'], retry=retry, timeout=timeout, metadata=metadata),
            request=request,
            items_field='errors',
            request_token_field='page_token',
            response_token_field='next_page_token',
        )
        return iterator



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import user_list_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__list__pb2
from google.ads.google_ads.v2.proto.services import user_list_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2


class UserListServiceStub(object):
  """Proto file describing the User List service.

  Service to manage user lists.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetUserList = channel.unary_unary(
        '/google.ads.googleads.v2.services.UserListService/GetUserList',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2.GetUserListRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__list__pb2.UserList.FromString,
        )
    self.MutateUserLists = channel.unary_unary(
        '/google.ads.googleads.v2.services.UserListService/MutateUserLists',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2.MutateUserListsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2.MutateUserListsResponse.FromString,
        )


class UserListServiceServicer(object):
  """Proto file describing the User List service.

  Service to manage user lists.
  """

  def GetUserList(self, request, context):
    """Returns the requested user list.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateUserLists(self, request, context):
    """Creates or updates user lists. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_UserListServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetUserList': grpc.unary_unary_rpc_method_handler(
          servicer.GetUserList,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2.GetUserListRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_user__list__pb2.UserList.SerializeToString,
      ),
      'MutateUserLists': grpc.unary_unary_rpc_method_handler(
          servicer.MutateUserLists,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2.MutateUserListsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_user__list__service__pb2.MutateUserListsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.UserListService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
